@@ -6,10 +6,10 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-09-29'; # DATE
 our $DIST = 'Sah-Schemas-JSON'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [str => {
-    summary => 'A string that contains a valid JSON',
+    summary => 'A string that contains valid JSON',
     'prefilters' => ['JSON::check_decode'],
     examples => [
         {value=>'', valid=>0, summary=>'Empty string'},
@@ -24,7 +24,7 @@ our $schema = [str => {
 }];
 
 1;
-# ABSTRACT: A string that contains a valid JSON
+# ABSTRACT: A string that contains valid JSON
 
 __END__
 
@@ -34,11 +34,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::json_str - A string that contains a valid JSON
+Sah::Schema::json_str - A string that contains valid JSON
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::json_str (from Perl distribution Sah-Schemas-JSON), released on 2021-09-29.
+This document describes version 0.003 of Sah::Schema::json_str (from Perl distribution Sah-Schemas-JSON), released on 2021-09-29.
 
 =head1 SYNOPSIS
 
